@@ -121,45 +121,34 @@ class Worker:
         
     def get_result(self, request_id):
         guid, request_hash = self._decode_id(request_id)
-        entity = self.table_client.get_entity(self.metadata_table_name, guid, request_hash)
+        entity = self.table_client.get_entity(self.metadata_table_name, guid, request_hash, select="Result,Error,StackTrace,State,Offset")
+        entity = self._expand_result(entity)
         return TaskResult.create_from_request_entity(entity)
 
     def get_results(self, guid):
-        entities = list(self.table_client.query_entities(self.metadata_table_name, filter="PartitionKey eq '%s'" % guid))
+        entities = list(
+            self.table_client.query_entities(
+                self.metadata_table_name, 
+                filter="PartitionKey eq '%s'" % guid, 
+                select="Result,Error,StackTrace,State,Offset"
+            )
+        )
+        entities = [self._expand_result(e) for e in entities]
         return [TaskResult.create_from_request_entity(entity) for entity in entities]
 
-    def process_messages_stateful(self, func):
-        state_row = list(self.table_client.query_entities(state_table))[0]
-        now = datetime.datetime.now(datetime.timezone.utc)
-        active_count = state_row['ActiveCount'].value
-        max_count = state_row['MaxCount'].value
-        if active_count >= max_count:
-            logging.info(enough_workers_message)
-            diff = now - state_row['UpdateDate']
-            if diff.total_seconds() > 300:
-                logging.info(workers_long_running)
-            else:
-                return
-        else:
-            state_row['ActiveCount'].value += 1
-            state_row['UpdateDate'] = now
-            self.table_client.update_entity(state_table, state_row)
+    def _expand_result(self, entity):
+        if "Result" not in entity:
+            return entity
 
-        try:
-            while True:
-                response = self.queue.receive_messages(messages_per_page=32)
-                messages = list(response)
-                logging.info(str(len(messages)))
-                if len(messages) == 0:
-                    break
-                for message in messages:
-                    content = base64.b64decode(message.content).decode("utf-8")
-                    self.process_message(content, func)
-                    self.queue.delete_message(message)
-        finally:
-            state_row['ActiveCount'].value = 0
-            state_row['UpdateDate'] = datetime.datetime.now(datetime.timezone.utc)
-            self.table_client.update_entity(state_table, state_row)
+        result_value = entity['Result']
+        if result_value is None:
+            return entity
+
+        if len(result_value.split("/")) == 4: # f"{self.worker_name}/Requests/{request_entity['PartitionKey']}/{request_entity['RowKey']}"
+            blob = self._get_output_blob(result_value)
+            result = blob.download_blob().readall().decode()
+            entity["Result"] = result
+        return entity
 
     def process_message(self, request_id, func):
         try:
@@ -173,6 +162,15 @@ class Worker:
             self._record_request_failure(request_entity, e)
             self._record_failure(request_id, e)
 
+    def _process_request_body(self, request_entity, func):
+        request_body = json.loads(request_entity["Request"])
+        response = func(request_body["Data"], request_body["Params"])
+        blob_name = f"{self.worker_name}/Request/{request_entity['PartitionKey']}/{request_entity['RowKey']}"
+        out_blob = self._get_output_blob(blob_name)
+        out_blob.upload_blob(json.dumps(response), timeout=1200, overwrite=True)
+        request_entity['Result'] = blob_name
+        self.table_client.update_entity(self.metadata_table_name, request_entity)
+
     def _process_blob(self, request_id, request_entity, func):
         blob_name, params, offset, retry_count, batch_count, next_chunk = self._read_metadata(request_entity)
         try:
@@ -327,14 +325,6 @@ class Worker:
     def _enqueue(self, request_id):
         self.queue.send_message(base64.b64encode(request_id.encode()).decode())
 
-    def _process_request_body(self, request_entity, func):
-        if "Request" not in request_entity:
-            return
-        request_body = json.loads(request_entity["Request"])
-        response = func(request_body["Data"], request_body["Params"])
-        request_entity['Result'] = json.dumps(response)
-        self.table_client.update_entity(self.metadata_table_name, request_entity)
-
     @staticmethod
     def _read_blob_by_chunks(input_blob):
         blob_data = input_blob.download_blob()
